@@ -29,13 +29,13 @@
 
 #include <stdlib.h>
 
+#include <gdesktop-enums.h>
 #include <gegl.h>
 #include <gexiv2/gexiv2.h>
 #include <gio/gio.h>
 #include <glib.h>
 #include <glib/gi18n.h>
 #include <grilo.h>
-#include <libgnome-desktop/gnome-bg.h>
 
 #include "photos-application.h"
 #include "photos-base-item.h"
@@ -162,11 +162,13 @@ static const gchar *REQUIRED_GEGL_OPS[] =
   "gegl:exposure",
   "gegl:gray",
   "gegl:load",
+  "gegl:noise-reduction",
   "gegl:nop",
   "gegl:pixbuf",
   "gegl:rotate-on-center",
   "gegl:save-pixbuf",
   "gegl:scale-ratio",
+  "gegl:unsharp-mask",
 
   /* Used by gegl:load */
   "gegl:jpg-load",
@@ -572,9 +574,15 @@ photos_application_gegl_init_fishes_idle (gpointer user_data)
 static gboolean
 photos_application_sanity_check_gegl (PhotosApplication *self)
 {
+  GeglConfig *config;
   gboolean ret_val = TRUE;
+  gboolean use_opencl;
   guint i;
 
+  config = gegl_config ();
+  g_object_get (config, "use-opencl", &use_opencl, NULL);
+  photos_debug (PHOTOS_DEBUG_GEGL, "Using OpenCL: %s", use_opencl ? "yes" : "no");
+
   for (i = 0; i < G_N_ELEMENTS (REQUIRED_GEGL_OPS); i++)
     {
       if (!gegl_has_operation (REQUIRED_GEGL_OPS[i]))
